<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey H.M. Taylor}
 * @copyright Onpub (TM). Copyright 2009, Onpubco.
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 */
class OnpubEditWebsite
{
  private $pdo;
  private $owebsite;
  private $sectionIDs;

  function __construct(PDO $pdo, $owebsite, $sectionIDs = NULL)
  {
    $this->pdo = $pdo;
    $this->owebsite = $owebsite;
    $this->sectionIDs = $sectionIDs;
  }

  public function display()
  {
    $osections = new OnpubSections($this->pdo);
    $owebsites = new OnpubWebsites($this->pdo);
    $oimages = new OnpubImages($this->pdo);
    $queryOptions = new OnpubQueryOptions();
    $queryOptions->includeSections = TRUE;

    try
    {
      $totalSections = $osections->count();
      $this->owebsite = $owebsites->get($this->owebsite->ID, $queryOptions);
      $queryOptions = new OnpubQueryOptions();
      $queryOptions->orderBy = "name";
      $queryOptions->order = "ASC";
      $websites = $owebsites->select($queryOptions);

      $queryOptions = new OnpubQueryOptions();
      $queryOptions->orderBy = "fileName";
      $queryOptions->order = "ASC";
      $images = $oimages->select($queryOptions);
    }
    catch (PDOException $e)
    {
      throw $e;
    }

    $widget = new OnpubWidgetHeader("Website " . $this->owebsite->ID . " - "
      . $this->owebsite->name);
    $widget->display();

    en('<form action="index.php" method="post" enctype="multipart/form-data">');
    en('<div>');
/*
        if ( $totalSections ) {
            en( '<a href="javascript:selectAll( sectionList ); submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt=""></a> <a href="javascript:deleteWebsite();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt=""></a>' );
        }
        else {
            en( '<a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.png" border="0" alt=""></a> <a href="javascript:deleteWebsite();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.png" border="0" alt=""></a>' );
        }
*/

    en(
      '<b>Name</b><br><input type="text" maxlength="255" size="75" name="name" value="'
      . htmlentities($this->owebsite->name) . '">', 1, 2);

    $message = "";

    if ($this->owebsite->url)
    {
      $go = ' <b><a href="' . $this->owebsite->url
        . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16"></a></b>';
    }
    else
    {
      $go = '';
    }

    en('<b>URL</b>' . $message
      . '<br><input type="text" maxlength="255" size="75" name="url" value="'
      . htmlentities($this->owebsite->url) . '">' . $go, 1, 2);

    $message = "";

    if (file_exists($this->owebsite->imagesDirectory))
    {
      if (!is_writable($this->owebsite->imagesDirectory))
      {
        $message
          = '<img src="gui/icons/drive_error.png" align="top" width="16" height="16" alt="Directory is not writable" title="Directory is not writable">';
      }
    }
    else
    {
      if ($this->owebsite->imagesDirectory)
      {
        $message
          = '<img src="gui/icons/drive_error.png" align="top" width="16" height="16" alt="Directory does not exist on '
          . $_SERVER['SERVER_NAME'] . '" title="Directory does not exist on '
          . $_SERVER['SERVER_NAME'] . '">';
      }
    }

    $message = "";

    if ($this->owebsite->imagesURL)
    {
      $message
        = '<br><small>Images uploaded to this website should be accessible from this URL</small>';
    }
    else
    {
      $message
        = '<br><small>Should be a URL to the Images Directory, example: http://onpubco.com/images/</small>';
    }

    if ($this->owebsite->imagesURL)
    {
      $go = ' <b><a href="' . $this->owebsite->imagesURL
        . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16"></a></b>';
    }
    else
    {
      $go = '';
    }

    en('<b>Images URL</b>' . $message
      . '<br><input type="text" maxlength="255" size="75" name="imagesURL" value="'
      . htmlentities($this->owebsite->imagesURL) . '">' . $go, 1, 2);

    en(
      '<b>Images Directory</b><br><small>Images uploaded to this website will be saved to this directory on <i>'
      . $_SERVER['SERVER_NAME']
        . '</i></small><br><input type="text" maxlength="255" size="75" name="imagesDirectory" value="'
      . htmlentities($this->owebsite->imagesDirectory) . '"> ' . $message,
      1, 2);

    en('<div class="yui-gd">');

    en('<div class="yui-u first">');
    en('<b>Created</b><br>'
      . $this->owebsite->getCreated()->format('M j, Y g:i:s A'), 1, 2);
    en('</div>');

    en('<div class="yui-u">');
    en('<b>Modified</b><br>'
      . $this->owebsite->getModified()->format('M j, Y g:i:s A'), 1, 2);
    en('</div>');

    en('</div>');

    $widget = new OnpubWidgetImages("Logo", $this->owebsite->imageID, $images,
      $this->owebsite);
    $widget->display();

    br(2);

    if ($totalSections)
    {
      $widget = new OnpubWidgetSections();
      $widget->websites = $websites;
      $widget->osections = $osections;
      $widget->heading = "All Sections";
      $widget->fieldName = "existingSections";
      $widget->display();

      en(
        '<a href="javascript:addExistingSection( existingSections, sectionList );"><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY . 'add.png" border="0" alt=""></a>');

      br(2);

      $widget = new OnpubWidgetSections();
      $widget->sectionIDs = $this->sectionIDs;
      $widget->websites = $websites;
      $widget->osections = $osections;
      $widget->heading = "Visible Sections";
      $widget->owebsite = $this->owebsite;
      $widget->display();

      en('<a href="javascript:moveSelectedOptionUp( sectionList );"><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY . 'up.png" border="0" alt=""></a><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY
          . 'buttonspacer.png" border="0" alt=""><a href="javascript:moveSelectedOptionDown( sectionList );"><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY
          . 'down.png" border="0" alt=""></a><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY
          . 'buttonspacer.png" border="0" alt=""><a href="javascript:removeSelectedSection( sectionList );"><img src="'
        . ONPUBGUI_IMAGE_DIRECTORY . 'remove.png" border="0" alt=""></a>',
        1, 2);
    }

    en(
      '<input type="submit" value="Save"> <input type="button" value="Delete" onclick="deleteWebsite();">');

    en('<input type="hidden" name="onpub" value="EditWebsiteProcess">');
    en('<input type="hidden" name="websiteID" value="' . $this->owebsite->ID
      . '">');

    en('</div>');
    en('</form>');

    en('<script type="text/javascript">');
    en('<!--');

    en('// convenience variables for form[0]\'s objects');
    en('var existingSections = document.forms[0].existingSections;');

    if (sizeof($images))
    {
      en('var sectionList = document.forms[0].elements[6];');
    }
    else
    {
      en('var sectionList = document.forms[0].elements[5];');
    }

    en('//-->');
    en('</script>');

    $widget = new OnpubWidgetFooter();
    $widget->display();
  }

  public function validate()
  {
    if (!$this->owebsite->name)
    {
      $this->owebsite->name = NULL;
      return FALSE;
    }

    return TRUE;
  }

  public function process()
  {
    $owebsites = new OnpubWebsites($this->pdo);

    $sections = array ();

    for ($i = 0; $i < sizeof($this->sectionIDs); $i++)
    {
      if ($this->sectionIDs[$i])
      {
        $section = new OnpubSection();

        $section->ID = $this->sectionIDs[$i];
        $section->websiteID = $this->owebsite->ID;

        $sections[] = $section;
      }
    }

    $this->owebsite->sections = $sections;

    try
    {
      $owebsites->update($this->owebsite);
    }
    catch (PDOException $e)
    {
      throw $e;
    }
  }

  public function delete()
  {
    $owebsites = new OnpubWebsites($this->pdo);

    try
    {
      $owebsites->delete($this->owebsite->ID);
    }
    catch (PDOException $e)
    {
      throw $e;
    }
  }
}
?>