<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey H.M. Taylor}
 * @copyright Onpub (TM). Copyright 2009, Onpubco.
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 */
class OnpubNewArticle
{
  private $pdo;
  private $oarticle;
  private $oauthor;
  private $tidyConfig;

  function __construct(PDO $pdo, OnpubArticle $oarticle, OnpubAuthor $oauthor,
    $tidyConfig = array ())
  {
    $this->pdo = $pdo;
    $this->oarticle = $oarticle;
    $this->oauthor = $oauthor;
    $this->tidyConfig = $tidyConfig;
  }

  public function display()
  {
    $owebsites = new OnpubWebsites($this->pdo);
    $osections = new OnpubSections($this->pdo);

    try
    {
      $queryOptions = new OnpubQueryOptions();
      $queryOptions->orderBy = "name";
      $queryOptions->order = "ASC";
      $websites = $owebsites->select($queryOptions);

      $queryOptions = new OnpubQueryOptions();
      $queryOptions->orderBy = "fileName";
      $queryOptions->order = "ASC";
    }
    catch (PDOException $e)
    {
      throw $e;
    }

    $widget = new OnpubWidgetHeader("New Article");
    $widget->display();

    en ('<form action="index.php" method="post">');
    en ('<div>');

    en ('<div class="yui-g">');

    en ('<div class="yui-u first">');

    if ($this->oarticle->title === NULL)
    {
      en(
        '<b>Title</b><br><input type="text" maxlength="255" size="40" name="title" value=""> <img src="gui/icons/exclamation.png" align="top" alt="Required field" title="Required field">',
        1, 2);
    }
    else
    {
      en(
        '<b>Title</b><br><input type="text" maxlength="255" size="40" name="title" value="'
        . htmlentities($this->oarticle->title) . '">', 1, 2);
    }

    en ('</div>');

    en ('<div class="yui-u">');

    en(
      '<b>Author</b><br><input type="text" maxlength="255" size="40" name="displayAs" value="'
      . htmlentities($this->oauthor->displayAs) . '">', 1, 2);

    en ('</div>');

    en ('</div>');

    en('<b>Content</b>', 1, 1);

    en ('<textarea rows="15" cols="80" name="content">'
      . htmlentities($this->oarticle->content) . '</textarea>');

    if (file_exists('gui/ckeditor/ckeditor.js'))
    {
      en('<script type="text/javascript" src="gui/ckeditor/ckeditor.js">'
        . '</script>');

      en('<script type="text/javascript">CKEDITOR.replace( "content" );'
        . '</script>');

      br();
    }
    else {
      br (2);
    }

    if (function_exists("tidy_repair_string"))
    {
      en('<b>HTML Tidy</b>', 1, 1);

      if ($this->tidyConfig['markup'])
      {
        en(
          '<input type="checkbox" id="id_markup" name="markup" value="1" checked="checked"> <label for="id_markup">Tidy HTML in Content</label>',
          1, 2);
      }
      else
      {
        en(
          '<input type="checkbox" id="id_markup" name="markup" value="1"> <label for="id_markup">Tidy HTML in Content</label>',
          1, 2);
      }
    }

    $widget = new OnpubWidgetDateCreated($this->oarticle->getCreated());
    $widget->display();

    if ($this->oarticle->url)
    {
      $go = ' <b><a href="' . $this->oarticle->url
        . '" target="_blank"><img src="gui/icons/world_go.png" border="0" align="top" alt="Go" title="Go" width="16" height="16"></a></b>';
    }
    else
    {
      $go = '';
    }

    br (2);

    en(
      '<b>URL</b><br><input type="text" maxlength="255" size="75" name="url" value="'
      . htmlentities($this->oarticle->url) . '">' . $go, 1, 2);

    $widget = new OnpubWidgetSections();
    $widget->sectionIDs = $this->oarticle->sectionIDs;
    $widget->websites = $websites;
    $widget->osections = $osections;
    $widget->display();

    en ('<input type="submit" value="Save">');

    en ('<input type="hidden" name="onpub" value="NewArticleProcess">');

    en ('</div>');
    en ('</form>');

    $widget = new OnpubWidgetFooter();
    $widget->display();
  }

  public function process()
  {
    $oarticles = new OnpubArticles($this->pdo);

    if ($this->oauthor->displayAs)
    {
      $authors = array ($this->oauthor);
      $this->oarticle->authors = $authors;
    }

    $content = OnpubDatabase::utf8Decode($this->oarticle->content);

    if (function_exists("tidy_repair_string"))
    {
      if ($this->tidyConfig['markup'])
      {
        $content = tidy_repair_string($content, $this->tidyConfig, "latin1");
      }
    }

    $this->oarticle->content = $content;

    try
    {
      $oarticles->insert($this->oarticle);
    }
    catch (PDOException $e)
    {
      throw $e;
    }
  }

  public function validate()
  {
    if (!$this->oarticle->title)
    {
      $this->oarticle->title = NULL;

      $content = OnpubDatabase::utf8Decode($this->oarticle->content);

      if (function_exists("tidy_repair_string"))
      {
        if ($this->tidyConfig['markup'])
        {
          $content = tidy_repair_string($content, $this->tidyConfig, "latin1");
        }
      }

      $this->oarticle->content = $content;

      return FALSE;
    }

    return TRUE;
  }
}
?>